
Visualisation and Plotting
++++++++++++++++++++++++++

Fleur specific Plotting
------------------------

.. automodule:: masci_tools.vis.fleur
   :members:

KKR specific Plotting
----------------------
.. automodule:: masci_tools.vis.kkr_plot_FS_qdos
   :members:

.. automodule:: masci_tools.vis.kkr_plot_bandstruc_qdos
   :members:

.. automodule:: masci_tools.vis.kkr_plot_dos
   :members:

.. automodule:: masci_tools.vis.kkr_plot_shapefun
   :members:

General Plotting
-----------------

.. automodule:: masci_tools.vis.parameters
   :members:

.. automodule:: masci_tools.vis.data
   :members:

.. automodule:: masci_tools.vis.common
   :members:

Matplotlib
^^^^^^^^^^^

.. automodule:: masci_tools.vis.matplotlib_plotter
   :members:

.. automodule:: masci_tools.vis.plot_methods
   :members:

Bokeh
^^^^^^^^^^^

.. automodule:: masci_tools.vis.bokeh_plotter
   :members:

.. automodule:: masci_tools.vis.bokeh_plots
   :members:

Calculation tools
+++++++++++++++++++++++++++

.. automodule:: masci_tools.tools.cf_calculation
   :members:

.. automodule:: masci_tools.tools.greensfunction
   :members:

.. automodule:: masci_tools.tools.greensf_calculations
   :members:

IO helper functions and file parsers
+++++++++++++++++++++++++++++++++++++

KKR related IO
----------------

.. automodule:: masci_tools.io.kkr_params
   :members:

.. automodule:: masci_tools.io.kkr_read_shapefun_info
   :members:

.. automodule:: masci_tools.io.parsers.kkrparser_functions
   :members:

.. automodule:: masci_tools.io.parsers.voroparser_functions
   :members:

.. automodule:: masci_tools.io.parsers.kkrimp_parser_functions
   :members:

Fleur related IO
------------------

Input/Output Parser
^^^^^^^^^^^^^^^^^^^

.. automodule:: masci_tools.io.parsers.fleur
   :members:

Inputgenerator related IO
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: masci_tools.io.fleur_inpgen
   :members:

Functions for modifying the input file
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: masci_tools.io.fleurxmlmodifier
   :members:

Functions/Classes for loading/validating fleur XML files
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: masci_tools.io.parsers.fleur.fleur_schema.schema_dict.SchemaDict
   :members:

.. automodule:: masci_tools.io.io_fleurxml
   :members:

Helper functions for the ``n_mmp_mat`` file
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: masci_tools.io.io_nmmpmat
   :members:


General HDF5 parser
-------------------------

.. automodule:: masci_tools.io.parsers.hdf5.reader
   :members:

.. automodule:: masci_tools.io.parsers.hdf5.recipes
   :members:

.. automodule:: masci_tools.io.parsers.hdf5.transforms
   :members:


Definition of default parsing tasks for fleur out.xml
-----------------------------------------------------

.. automodule:: masci_tools.io.parsers.fleur.default_parse_tasks
   :members:

.. automodule:: masci_tools.io.parsers.fleur.task_migrations
   :members:
